ECE 4180 Lab 1 Part 7

Dependencies:   MCP23S17 mbed

Fork of MCP23S17_Basic_IO_Demo by jim hamblen

Revision:
3:d163db2be986
Parent:
2:934a0500abde
--- a/main.cpp	Fri Jan 28 02:04:05 2011 +0000
+++ b/main.cpp	Tue Oct 09 00:34:52 2018 +0000
@@ -13,10 +13,10 @@
 #include "MCP23S17.h"
 // Create SPI bus
 SPI spi(p5, p6, p7);
-// 
+//
 // Wiring Connections:
 // mbed p5,p6,p7 are tied to MCP23S17 SI, SO, SCK pins
 // mbed p20 to MCP23S17 CS
 // MCP23S17 reset pin pulled high
 // MCP23S17 GPA0 connected to GPB0 for loopback test
 // A0, A1, A2 of the MCP23S17  are tied to ground on the breadboard, so the 8-bit address for writes is 0x40
@@ -24,15 +24,16 @@
 char Opcode = 0x40;
 
 // Next create a MCP23S17
-// mbed p20 is connected to ~chipSelect on the MCP23S17
-MCP23S17 chip = MCP23S17(spi, p20, Opcode);
+// mbed p19 is connected to ~chipSelect on the MCP23S17
+MCP23S17 chip = MCP23S17(spi, p19, Opcode);
 
 // Optional software reset - mbed p14 to MCP23S17 reset pin
 // DigitalOut reset(p14);
 
 DigitalOut led1(LED1); // mbed LED1 is used for test status display
 
-int main() {
+int main()
+{
 //  The MCP23S17 reset pin can just be pulled high, since it has a power on reset circuit.
 //  The reset pin can be used for a software forced reset by pulling it low with an mbed GPIO pin.
 //  But just leave it pulled high for this simple demo code.
@@ -48,19 +49,8 @@
 //  Set all 8 Port B bits to input direction
     chip.direction(PORT_B, 0xFF);
     led1=0;
-//  Start Loopback test sending out and reading back values
-//  loopback test uses A0 and B0 pins - so use a wire to jumper those two pins on MCP23S17 together
+
     while (1) {
-        // write 0xAA to MCP23S17 Port A
-        chip.write(PORT_A, 0xAA);
-        wait(.5);
-        // read back value from MCP23S17 Port B and display B0 on mbed led1
-        led1 = chip.read(PORT_B)& 0x01;
-        // write 0x55 to MCP23S17 Port A
-        chip.write(PORT_A, 0x55);
-        wait(.5);
-        // read back value from MCP23S17 Port B and display B0 on mbed led1
-        led1 = chip.read(PORT_B)& 0x01;
-        // led1 should blink slowly when it is all working
+        chip.write(PORT_A, !chip.read(PORT_B) & 0x01);
     }
 }
@@ -13,10 +13,10 @@
 // Wiring Connections:
 // mbed p5,p6,p7 are tied to MCP23S17 SI, SO, SCK pins
-// mbed p20 to MCP23S17 CS
+// mbed p19 to MCP23S17 CS
 // MCP23S17 reset pin pulled high
 // MCP23S17 GPA0 connected to GPB0 for loopback test